@@ -1,6 +1,7 @@
 import hashlib
 import json
 import jsonschema
+import os
 
 from squad_client import logging
 from squad_client.shortcuts import submit_results
@@ -46,6 +47,10 @@ tuxbuild_schema = {
     }],
 }
 
+ALLOWED_METADATA = [
+    "git_branch", "git_commit", "git_describe", "git_ref", "git_repo", "git_sha", "git_short_log", "kernel_version", "make_kernelversion",
+]
+
 
 class SubmitTuxbuildCommand(SquadClientCommand):
     command = "submit-tuxbuild"
@@ -64,6 +69,25 @@ class SubmitTuxbuildCommand(SquadClientCommand):
             help="File with tuxbuild results to submit",
         )
 
+    def _build_metadata(self, builds):
+        metadata = {k: v for k, v in builds[0].items() if k in ALLOWED_METADATA}
+
+        # We expect git_commit, but tuxmake calls it git_sha
+        metadata.update({"git_commit": metadata.get("git_sha")})
+
+        # We expect `git_branch`, but tuxmake calls it `git_ref`
+        # `git_ref` will sometimes be null
+        metadata.update({"git_branch": metadata.get("git_ref")})
+
+        # If `git_ref` is null, use `KERNEL_BRANCH` from the CI environment
+        if metadata.get("git_branch") is None:
+            metadata.update({"git_branch": os.getenv("KERNEL_BRANCH")})
+
+        # We expect `make_kernelversion`, but tuxmake calls it `kernel_version`
+        metadata.update({"make_kernelversion": metadata.get("kernel_version")})
+
+        return metadata
+
     def _load_builds(self, path):
         builds = None
         try:
@@ -124,6 +148,7 @@ class SubmitTuxbuildCommand(SquadClientCommand):
                 build_version=description,
                 env_slug=arch,
                 tests=result,
+                metadata=self._build_metadata(builds),
             )
 
         return True
